@@ -1,7 +1,7 @@
 package RoleWithAttributes;
-our $VERSION = '0.14_01';
+our $VERSION = '0.16_01';
 
-use Moose::Role -traits => 'MethodAttributes';
+use MooseX::MethodAttributes::Role;
 use namespace::clean -except => 'meta';
 
 sub foo : AnAttr { 'foo' }
